@@ -21,6 +21,7 @@
 
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
+#include <kdebug.h>
 #include <klocale.h>
 #include <kglobal.h>
 #include <kstandarddirs.h>
@@ -60,6 +61,7 @@ extern "C" KDE_EXPORT int kdemain(int argc, char *argv[])
 
    KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
    bool hasArgKeepvisibility = args->isSet("keepvisibility");
+   //kDebug(67100) <<  "hasArgKeepvisibility=" << hasArgKeepvisibility;
    KMixApp::keepVisibility(hasArgKeepvisibility);
 
    if (!KMixApp::start())
